@@ -7,6 +7,11 @@ unversioned_url <- function(...) {
   paste(..., sep = "/")
 }
 
+# Make an alias of unversioned_url to help us be able to search for the places
+# where we call the unversioned API, but not be misled by places we've left in
+# for backwards compatibility.
+unversioned_fallback_url <- unversioned_url
+
 valid_page_size <- function(x, min = 1, max = 500) {
   # This could be changed to error if x is outside the range
   min(max(min, x), max)
@@ -17,7 +22,12 @@ generate_R6_print_output <- # nolint: object_name_linter
     con <- Connect$new(server = "http://test_host", api_key = "test_key")
     bnd <- Bundle$new(path = "/test/path")
 
-    ex_content <- list(guid = "content-guid", title = "content-title", url = "http://content-url")
+    ex_content <- list(
+      guid = "content-guid",
+      title = "content-title",
+      dashboard_url = "http://test_host/connect/#/apps/content-guid/",
+      url = "http://content-url"
+    )
     cnt1 <- Content$new(connect = con, ex_content)
 
     ex_task <- list(task_id = "task-id")
@@ -54,7 +64,12 @@ validate_R6_class <- # nolint: object_name_linter
   function(instance, class) {
     obj <- rlang::enquo(instance)
     if (!R6::is.R6(instance) || !inherits(instance, class)) {
-      stop(paste(rlang::quo_text(obj), "must be an R6", glue::glue_collapse(class, sep = " or "), "object"))
+      stop(paste(
+        rlang::quo_text(obj),
+        "must be an R6",
+        glue::glue_collapse(class, sep = " or "),
+        "object"
+      ))
     }
     invisible(TRUE)
   }
@@ -62,11 +77,17 @@ validate_R6_class <- # nolint: object_name_linter
 # super useful examples
 # https://github.com/tidyverse/tibble/blob/master/R/compat-lifecycle.R
 warn_experimental <- function(name) {
-  if (rlang::is_true(rlang::peek_option("connectapi_disable_experimental_warnings"))) {
+  if (
+    rlang::is_true(rlang::peek_option(
+      "connectapi_disable_experimental_warnings"
+    ))
+  ) {
     return(invisible(NULL))
   }
   warn_once(
-    msg = glue::glue("The `{name}` function is experimental and subject to change without warning in a future release"),
+    msg = glue::glue(
+      "The `{name}` function is experimental and subject to change without warning in a future release"
+    ),
     id = paste0(name, "-experimental")
   )
 }
@@ -83,7 +104,9 @@ warn_dire <- function(name) {
     return(invisible(NULL))
   }
   warn_once(
-    msg = glue::glue("DO NOT USE IN PRODUCTION - The {name} function is for internal testing purposes only"),
+    msg = glue::glue(
+      "DO NOT USE IN PRODUCTION - The {name} function is for internal testing purposes only"
+    ),
     id = paste0(name, "-dire")
   )
 }
@@ -125,7 +148,9 @@ safe_server_settings <- function(client) {
     },
     error = function(e) {
       message(
-        glue::glue("Problem talking to Posit Connect at {client$server}/__api__/server_settings")
+        glue::glue(
+          "Problem talking to Posit Connect at {client$server}/__api__/server_settings"
+        )
       )
       stop(e)
     }
@@ -136,7 +161,6 @@ safe_server_settings <- function(client) {
 safe_server_version <- function(client) {
   version <- safe_server_settings(client)$version
   if (is.null(version) || nchar(version) == 0) {
-    message("Version information is not exposed by this Posit Connect instance.")
     version <- NA
   }
   version
@@ -165,18 +189,27 @@ error_if_less_than <- function(using_version, tested_version) {
 
 compare_connect_version <- function(using_version, tested_version) {
   as.integer(
-    compareVersion(simplify_version(using_version), simplify_version(tested_version))
+    compareVersion(
+      simplify_version(using_version),
+      simplify_version(tested_version)
+    )
   )
 }
 
-warn_untested_connect <- function(using_version, minimum_tested_version = "1.8.8.2") {
+warn_untested_connect <- function(
+  using_version,
+  minimum_tested_version = "1.8.8.2"
+) {
   comp <- compare_connect_version(using_version, minimum_tested_version)
   if (!is.na(using_version) && (comp < 0)) {
-    warn_once(glue::glue(
-      "You are using an older version of Posit Connect ",
-      "({using_version}) than is tested ({minimum_tested_version}). ",
-      "Some APIs may not function as expected."
-    ), id = "old-connect")
+    warn_once(
+      glue::glue(
+        "You are using an older version of Posit Connect ",
+        "({using_version}) than is tested ({minimum_tested_version}). ",
+        "Some APIs may not function as expected."
+      ),
+      id = "old-connect"
+    )
   }
   invisible()
 }
@@ -194,8 +227,32 @@ endpoint_does_not_exist <- function(res) {
     !("code" %in% names(httr::content(res, as = "parsed")))
 }
 
+# Extract the Connect error code from a response
+error_code <- function(res) {
+  cont <- httr::content(res)
+  if ("code" %in% names(cont)) {
+    cont[["code"]]
+  } else {
+    # Return -1 if there is no error, just so we aren't comparing NA or NULL
+    -1
+  }
+}
+
 # Returns `TRUE` if we're running on Connect as determined by the
 # `RSTUDIO_PRODUCT` env var, else `FALSE`.
 on_connect <- function() {
   Sys.getenv("RSTUDIO_PRODUCT") == "CONNECT"
 }
+
+# Returns `TRUE` if running via testthat
+is_testing <- function() {
+  identical(Sys.getenv("TESTTHAT"), "true")
+}
+
+# Calls `message()` if not running in testthat. Useful for messages that would
+# otherwise appear very frequently in test output.
+message_if_not_testing <- function(...) {
+  if (!is_testing()) {
+    message(...)
+  }
+}
