@@ -1,9 +1,11 @@
 structure(
   list(
-    url = "__api__/applications/01234567/image", status_code = 200L,
+    url = "__api__/applications/01234567/image",
+    status_code = 200L,
     headers = structure(list(
       `content-type` = "image/jpeg"
-    )), content = as.raw(c(
+    )),
+    content = as.raw(c(
       0x4e,
       0x41
     ))
