@@ -21,7 +21,9 @@ without_internet({
     con <- Connect$new(server = "https://connect.example", api_key = "fake")
     expect_GET(
       con$repo_branches("https://github.com/posit-dev/connectapi"),
-      repo_path("branches?url=https%3A%2F%2Fgithub.com%2Fposit-dev%2Fconnectapi")
+      repo_path(
+        "branches?url=https%3A%2F%2Fgithub.com%2Fposit-dev%2Fconnectapi"
+      )
     )
   })
 
@@ -29,7 +31,9 @@ without_internet({
     con <- Connect$new(server = "https://connect.example", api_key = "fake")
     expect_GET(
       con$repo_manifest_dirs("https://github.com/posit-dev/connectapi", "main"),
-      repo_path("manifest-dirs?url=https%3A%2F%2Fgithub.com%2Fposit-dev%2Fconnectapi&branch=main")
+      repo_path(
+        "manifest-dirs?url=https%3A%2F%2Fgithub.com%2Fposit-dev%2Fconnectapi&branch=main"
+      )
     )
   })
 })
